==> onboarding-springboot-0.13.0-sources.jar: org/kie/kogito/examples/onboarding/SetupPayrollModelInput.java <==
package org.kie.kogito.examples.onboarding;

import java.util.Map;
import java.util.HashMap;

public class SetupPayrollModelInput implements org.kie.kogito.Model {

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("taxRate", this.taxRate);
        params.put("vacationDays", this.vacationDays);
        params.put("payroll", this.payroll);
        params.put("employee", this.employee);
        params.put("paymentDate", this.paymentDate);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.taxRate = (java.lang.Double) params.get("taxRate");
        this.vacationDays = (java.lang.Integer) params.get("vacationDays");
        this.payroll = (org.kie.kogito.examples.onboarding.Payroll) params.get("payroll");
        this.employee = (org.kie.kogito.examples.onboarding.Employee) params.get("employee");
        this.paymentDate = (java.util.Date) params.get("paymentDate");
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "taxRate")
    @javax.validation.Valid()
    private java.lang.Double taxRate;

    public java.lang.Double getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(java.lang.Double taxRate) {
        this.taxRate = taxRate;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "vacationDays")
    @javax.validation.Valid()
    private java.lang.Integer vacationDays;

    public java.lang.Integer getVacationDays() {
        return vacationDays;
    }

    public void setVacationDays(java.lang.Integer vacationDays) {
        this.vacationDays = vacationDays;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "payroll")
    @javax.validation.Valid()
    private org.kie.kogito.examples.onboarding.Payroll payroll;

    public org.kie.kogito.examples.onboarding.Payroll getPayroll() {
        return payroll;
    }

    public void setPayroll(org.kie.kogito.examples.onboarding.Payroll payroll) {
        this.payroll = payroll;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "employee")
    @javax.validation.Valid()
    private org.kie.kogito.examples.onboarding.Employee employee;

    public org.kie.kogito.examples.onboarding.Employee getEmployee() {
        return employee;
    }

    public void setEmployee(org.kie.kogito.examples.onboarding.Employee employee) {
        this.employee = employee;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "paymentDate")
    @javax.validation.Valid()
    private java.util.Date paymentDate;

    public java.util.Date getPaymentDate() {
        return paymentDate;
    }

    public void setPaymentDate(java.util.Date paymentDate) {
        this.paymentDate = paymentDate;
    }
}

==> onboarding-springboot-0.14.0-sources.jar: org/kie/kogito/examples/onboarding/SetupPayrollModelInput.java <==
package org.kie.kogito.examples.onboarding;

import java.util.Map;
import java.util.HashMap;

public class SetupPayrollModelInput implements org.kie.kogito.Model {

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("taxRate", this.taxRate);
        params.put("vacationDays", this.vacationDays);
        params.put("payroll", this.payroll);
        params.put("employee", this.employee);
        params.put("paymentDate", this.paymentDate);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.taxRate = (java.lang.Double) params.get("taxRate");
        this.vacationDays = (java.lang.Integer) params.get("vacationDays");
        this.payroll = (org.kie.kogito.examples.onboarding.Payroll) params.get("payroll");
        this.employee = (org.kie.kogito.examples.onboarding.Employee) params.get("employee");
        this.paymentDate = (java.util.Date) params.get("paymentDate");
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "taxRate")
    @javax.validation.Valid()
    private java.lang.Double taxRate;

    public java.lang.Double getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(java.lang.Double taxRate) {
        this.taxRate = taxRate;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "vacationDays")
    @javax.validation.Valid()
    private java.lang.Integer vacationDays;

    public java.lang.Integer getVacationDays() {
        return vacationDays;
    }

    public void setVacationDays(java.lang.Integer vacationDays) {
        this.vacationDays = vacationDays;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "payroll")
    @javax.validation.Valid()
    private org.kie.kogito.examples.onboarding.Payroll payroll;

    public org.kie.kogito.examples.onboarding.Payroll getPayroll() {
        return payroll;
    }

    public void setPayroll(org.kie.kogito.examples.onboarding.Payroll payroll) {
        this.payroll = payroll;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "employee")
    @javax.validation.Valid()
    private org.kie.kogito.examples.onboarding.Employee employee;

    public org.kie.kogito.examples.onboarding.Employee getEmployee() {
        return employee;
    }

    public void setEmployee(org.kie.kogito.examples.onboarding.Employee employee) {
        this.employee = employee;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "paymentDate")
    @javax.validation.Valid()
    private java.util.Date paymentDate;

    public java.util.Date getPaymentDate() {
        return paymentDate;
    }

    public void setPaymentDate(java.util.Date paymentDate) {
        this.paymentDate = paymentDate;
    }

    public SetupPayrollModel toModel() {
        SetupPayrollModel result = new SetupPayrollModel();
        result.setTaxRate(getTaxRate());
        result.setVacationDays(getVacationDays());
        result.setPayroll(getPayroll());
        result.setEmployee(getEmployee());
        result.setPaymentDate(getPaymentDate());
        return result;
    }
}
